| exteriorEdges | R Documentation |
Returns the edges of a mesh whose corresponding dihedral angles are not too flat.
exteriorEdges(edgesDF, angleThreshold = 1)
edgesDF |
the dataframe returned by the |
angleThreshold |
maximum deviation in degrees from the flat angle; for
example if |
An integer matrix giving the vertex indices of the exterior edges.
Once you get the exterior edges, say in extEdges, then you can
get the indices of the exterior vertices with
which(table(extEdges) != 2).
library(cgalMeshes)
library(rgl)
mesh <- cgalMesh$new(dodecahedron3d())
extEdges <- exteriorEdges(mesh$getEdges())
vertices <- mesh$getVertices()
open3d(windowRect = 50 + c(0, 0, 512, 512), zoom = 0.9)
shade3d(dodecahedron3d(), color = "tomato")
plotEdges(vertices, extEdges)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.